pub struct BufferedPansnFileIterator { /* private fields */ }Expand description
Iterator that buffers entire file in memory and outputs in sample-grouped order Much faster than random access for files with non-contiguous sample ordering
Implementations