pub struct Segment {
pub data: Contig,
pub front_kmer: u64,
pub back_kmer: u64,
pub front_kmer_is_dir: bool,
pub back_kmer_is_dir: bool,
}Expand description
A segment of a contig bounded by splitter k-mers
Fields
data: ContigThe sequence data of this segment
front_kmer: u64K-mer value at the start of the segment (or MISSING_KMER if at contig start)
back_kmer: u64K-mer value at the end of the segment (or MISSING_KMER if at contig end)
front_kmer_is_dir: boolWhether front k-mer is in direct orientation (for C++ AGC’s is_dir_oriented())
back_kmer_is_dir: boolWhether back k-mer is in direct orientation (for C++ AGC’s is_dir_oriented())
Implementations