#[repr(C)]pub struct SplitterChecker {
pub splitters: *mut u64,
pub len: usize,
}Expand description
Create a splitter checker with proper data structures
This matches C++ AGC’s use of both bloom filter and hash set. For now, we’ll use a simpler approach and just return a sorted vector that can be binary searched.
Returns a pointer to a sorted array of splitters that must be freed with ragc_free_splitter_checker().
Fields
splitters: *mut u64len: usizeAuto Trait Implementations
impl !Send for SplitterChecker
impl !Sync for SplitterChecker
impl Freeze for SplitterChecker
impl RefUnwindSafe for SplitterChecker
impl Unpin for SplitterChecker
impl UnsafeUnpin for SplitterChecker
impl UnwindSafe for SplitterChecker