Segment

Struct Segment 

pub struct Segment {
    pub data: Contig,
    pub front_kmer: u64,
    pub back_kmer: u64,
    pub front_kmer_is_dir: bool,
    pub back_kmer_is_dir: bool,
}
A segment of a contig bounded by splitter k-mers

Fields

data: Contig

The sequence data of this segment

front_kmer: u64

K-mer value at the start of the segment (or MISSING_KMER if at contig start)

back_kmer: u64

K-mer value at the end of the segment (or MISSING_KMER if at contig end)

front_kmer_is_dir: bool

Whether front k-mer is in direct orientation (for C++ AGC’s is_dir_oriented())

back_kmer_is_dir: bool

Whether back k-mer is in direct orientation (for C++ AGC’s is_dir_oriented())

Implementations

Source

impl Segment

pub fn new( data: Contig, front_kmer: u64, back_kmer: u64, front_kmer_is_dir: bool, back_kmer_is_dir: bool, ) -> Self

Create a new segment

pub fn len(&self) -> usize

Get the length of the segment

pub fn is_empty(&self) -> bool

Check if the segment is empty